@@ -5,7 +5,7 @@ package App::ElasticSearch::Utilities::Connection;
 use strict;
 use warnings;
 
-our $VERSION = '7.0'; # VERSION
+our $VERSION = '7.9.1'; # VERSION
 
 use App::ElasticSearch::Utilities::HTTPRequest;
 use CLI::Helpers qw(:output);
@@ -76,6 +76,7 @@ sub _build_ua {
         keep_alive        => 3,
         agent             => sprintf("%s/%0.1f (Perl %s)", __PACKAGE__, $local_version, $^V),
         protocols_allowed => [qw(http https)],
+        timeout           => $self->timeout,
     );
     debug({color=>'cyan'}, sprintf "Initialized a UA: %s", $ua->agent);
 
@@ -172,7 +173,7 @@ sub request {
     my $req = App::ElasticSearch::Utilities::HTTPRequest->new( $method => $uri->as_string );
     $req->content($body) if defined $body;
 
-    return $self->ua->simple_request( $req );
+    return $self->ua->request( $req );
 }
 
 
@@ -225,7 +226,7 @@ App::ElasticSearch::Utilities::Connection - Abstract the connection element
 
 =head1 VERSION
 
-version 7.0
+version 7.9.1
 
 =head1 SYNOPSIS
 
@@ -313,7 +314,7 @@ Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Brad Lhotsky.
+This software is Copyright (c) 2021 by Brad Lhotsky.
 
 This is free software, licensed under:
 
