@@ -3,8 +3,9 @@ package App::ElasticSearch::Utilities::VersionHacks;
 
 use strict;
 use warnings;
+use version;
 
-our $VERSION = '7.0'; # VERSION
+our $VERSION = '7.9.1'; # VERSION
 
 use Const::Fast;
 use CLI::Helpers qw(:all);
@@ -44,6 +45,9 @@ my %CALLBACKS = (
     '_cluster/state' => {
         default => \&_cluster_state_1_0,
     },
+    '_search' => {
+        default => \&_search_params,
+    },
 );
 
 my $version;
@@ -97,7 +101,7 @@ sub _fix_version_request {
             }
             elsif(exists $CALLBACKS{$url}->{default}) {
                 debug({indent=>1,color=>'yellow'}, "+ Callback dispatched for $url by default rule");
-                ($url,$options,$data) = $CALLBACKS{$url}->{default}->($url,$options,$data);
+                ($url,$options,$data) = $CALLBACKS{$url}->{default}->($url,$options,$data,$version);
             }
         }
     }
@@ -150,6 +154,23 @@ sub _cluster_state_1_0 {
     return ($url,$options,$data);
 }
 
+sub _search_params {
+    my ($url,$options,$data,$version) = @_;
+
+    my @invalid = ();
+    push @invalid, "track_total_hits"       if qv($version) < qv("6.0.0");
+    push @invalid, "rest_total_hits_as_int" if qv($version) < qv("7.0.0");
+
+    if( @invalid && exists $options->{uri_param} ) {
+        foreach my $invalid ( @invalid ) {
+            delete $options->{uri_param}{$invalid}
+                if exists $options->{uri_param}{$invalid};
+        }
+    }
+
+    return ($url,$options,$data);
+}
+
 1;
 
 __END__
@@ -162,7 +183,7 @@ App::ElasticSearch::Utilities::VersionHacks - Fix version issues to support all
 
 =head1 VERSION
 
-version 7.0
+version 7.9.1
 
 =head1 AUTHOR
 
@@ -170,7 +191,7 @@ Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Brad Lhotsky.
+This software is Copyright (c) 2021 by Brad Lhotsky.
 
 This is free software, licensed under:
 
