@@ -7,7 +7,6 @@ use warnings;
 use App::ElasticSearch::Utilities qw(:all);
 use CLI::Helpers qw(:all);
 use Getopt::Long qw(:config no_ignore_case no_ignore_case_always);
-use Hash::Flatten qw(flatten);
 use Pod::Usage;
 use POSIX qw(ceil);
 
@@ -31,7 +30,7 @@ GetOptions(\%opt,
     'index-basename=s',
     'date-separator=s',
     'timezone=s',
-    'allocation-exclude=s%',
+    'skip-alias=s@',
     # Basic options
     'help|h',
     'manual|m',
@@ -55,8 +54,7 @@ my %CFG = (
     bloom                => 0,
     optimize             => 0,
     replicas             => 0,
-    'allocation-exclude' => 0,
-    'allocation-require' => 0,
+    'skip-alias'         => [],
 );
 # Extract from our options if we've overridden defaults
 foreach my $setting (keys %CFG) {
@@ -78,6 +76,10 @@ else {
     }
     pod2usage(-message => "No operation selected, use --close, --delete, --optimize, or --replicas.", -exitval => 1) unless $operate;
 }
+# Set skip alias hash
+push @{ $CFG{'skip-alias'} }, qw( .hold .do_not_erase );
+my %SKIP = map { $_ => 1 } @{ $CFG{'skip-alias'} };
+
 # Can't have replicas-min below 0
 $CFG{'replicas-min'} = 0 if $CFG{'replicas-min'} < 0;
 
@@ -111,6 +113,21 @@ foreach my $index (sort @indices) {
         next;
     }
 
+    # Get aliases from index root
+    my %aliases  = ();
+    my $idx_meta = es_request($index);
+    if( exists $idx_meta->{$index}{aliases} ) {
+        my $skipped;
+        foreach my $alias ( keys %{ $idx_meta->{$index}{aliases} } ) {
+            $skipped = $alias if exists $SKIP{$alias};
+            last if $skipped;
+        }
+        if( $skipped ) {
+            output("$index contains a skipped alias: $skipped");
+            next;
+        }
+    }
+
     # Delete the Index if it's too old
     if( $CFG{delete} && $CFG{'delete-days'} <= $days_old ) {
         output({color=>"red"}, "$index will be deleted.");
@@ -223,7 +240,7 @@ es-daily-index-maintenance.pl - Run to prune old indexes and optimize existing
 
 =head1 VERSION
 
-version 7.0
+version 7.9.1
 
 =head1 SYNOPSIS
 
@@ -244,6 +261,7 @@ Options:
     --replicas-age      Age of the index to reach the minimum replicas (default:60)
     --replicas-min      Minimum number of replicas this index may have (default:0)
     --replicas-max      Maximum number of replicas this index may have (default:1)
+    --skip-alias        Indexes with these aliases will be skipped from all maintenance, can be set more than once
 
 From App::ElasticSearch::Utilities:
 
@@ -340,6 +358,17 @@ The maximum number of replicas to allow replica aging to set.  The default is 1
 
     --replicas-max=2
 
+=item B<skip-alias>
+
+Can be set more than once.  Any indexes with an alias that matches this list is
+skipped from operations.  This is a useful, lightweight mechanism to preserve
+indexes.
+
+    --skip-alias preserve --skip-alias pickle
+
+In addition to user specified aliases, the aliases C<.hold> and
+C<.do_not_erase> will always be excluded.
+
 =back
 
 =head1 AUTHOR
@@ -348,7 +377,7 @@ Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Brad Lhotsky.
+This software is Copyright (c) 2021 by Brad Lhotsky.
 
 This is free software, licensed under:
 
