@@ -4,15 +4,12 @@
 use strict;
 use warnings;
 
-$|=1;           # Flush STDOUT
-
 use App::ElasticSearch::Utilities qw(:all);
 use App::ElasticSearch::Utilities::Query;
 use App::ElasticSearch::Utilities::QueryString;
 use Carp;
 use CLI::Helpers qw(:all);
 use Getopt::Long qw(:config no_ignore_case no_ignore_case_always);
-use Hash::Flatten qw(flatten);
 use JSON::MaybeXS qw(:legacy);
 use Pod::Usage;
 use POSIX qw(strftime);
@@ -30,7 +27,7 @@ GetOptions(\%OPT, qw(
     bg-filter=s
     by=s
     desc
-    exists=s
+    exists=s@
     fields
     filter
     format=s
@@ -39,9 +36,10 @@ GetOptions(\%OPT, qw(
     manual|m
     match-all
     max-batch-size=i
-    missing=s
+    missing=s@
     no-decorators|no-header
     no-implications|no-imply
+    precision=i
     prefix=s@
     pretty
     show=s@
@@ -52,11 +50,15 @@ GetOptions(\%OPT, qw(
     top=s
     interval=s
     with=s@
+    or
 ));
 
 # Search string is the rest of the argument string
 my $context = $OPT{filter} ? 'filter' : 'must';
-my $qs = App::ElasticSearch::Utilities::QueryString->new( $OPT{filter} ? (qw(context filter)) : () );
+my $qs = App::ElasticSearch::Utilities::QueryString->new(
+            $OPT{filter} ?  (context => 'filter') : (),
+            default_join => $OPT{or} ? 'OR' : 'AND',
+);
 my $q = exists $OPT{'match-all'} && $OPT{'match-all'}
             ? App::ElasticSearch::Utilities::Query->new($context => { match_all => {} })
             : $qs->expand_query_string(@ARGV);
@@ -93,12 +95,14 @@ my %CONFIG = (
                : $OPT{format} ? lc $OPT{format}
                : 'yaml',
     'max-batch-size' => $OPT{'max-batch-size'} || 50,
+    precision => $OPT{precision} || 3,
     $OPT{timestamp} ? ( timestamp => $OPT{timestamp} ) : (),
 );
 $OPT{'no-decorators'} = 1 if $CONFIG{format} eq 'json';
 $CONFIG{pretty} = $OPT{pretty} ? 1
                 : $CONFIG{format} =~ /pretty/ ? 1
                 : 0;
+$CONFIG{decimal_format} = "%0.$CONFIG{precision}f";
 #------------------------------------------------------------------------#
 # Handle Indices
 my $ORDER = exists $OPT{asc} && $OPT{asc} ? 'asc' : 'desc';
@@ -124,6 +128,9 @@ foreach my $index (sort by_index_age keys %indices) {
     }
 }
 
+# Set fields so we know how to construct complex aggs
+$q->fields_meta( \%FIELDS );
+
 #------------------------------------------------------------------------#
 # Figure out the timestamp
 $CONFIG{timestamp} ||= es_globals('timestamp') || '@timestamp';
@@ -165,6 +172,7 @@ if ( exists $OPT{show} && scalar @{ $OPT{show} } ) {
     foreach my $args (@{ $OPT{show} }) {
         push @SHOW, grep { defined && length } split /,/, $args;
     }
+    $q->set_fields([$CONFIG{timestamp},@SHOW]);
 }
 # How to sort
 my $SORT = [ { $CONFIG{timestamp} => $ORDER } ];
@@ -190,21 +198,17 @@ pod2usage({-exitval=>1, -verbose=>0, -sections=>'SYNOPSIS', -msg=>'Please specif
     if exists $OPT{tail} && !@SHOW;
 
 # Process extra parameters
-if( exists $OPT{exists} ) {
-    foreach my $field (split /[,:]/, $OPT{exists}) {
-        $q->add_bool( $context => { exists => { field => $field } } );
+foreach my $presence ( qw( exists missing ) ) {
+    if( exists $OPT{$presence} ) {
+        my @fields = map { split /[,:]/ } (is_arrayref($OPT{$presence}) ? @{ $OPT{$presence} } : ($OPT{$presence}));
+        my $context = $presence eq 'exists' ? 'must' : 'must_not';
+        foreach my $field (@fields) {
+            $q->add_bool( $context => { exists => { field => $field } } );
+        }
     }
 }
-if( exists $OPT{missing} ) {
-    foreach my $field (split /[,:]/, $OPT{missing}) {
-        $q->add_bool( must_not => { exists => { field => $field } } );
-    }
-}
-my $DONE = 0;
-local $SIG{INT} = sub { $DONE=1 };
 
 my %SUPPORTED_AGGREGATIONS = map {$_=>'simple_value'} qw(cardinality sum min max avg);
-my $SUBAGG = undef;
 my $agg_header = '';
 if( exists $OPT{top} ) {
     my @top = split /:/, $OPT{top};
@@ -220,7 +224,6 @@ if( exists $OPT{top} ) {
     if( $OPT{by}) {
         my ($type,$field) = split /\:/, $OPT{by};
         if( exists $SUPPORTED_AGGREGATIONS{$type} ) {
-            $SUBAGG = $type;
             $sub_agg{by} = { $type => {field => $field} };
         }
         else {
@@ -243,7 +246,7 @@ if( exists $OPT{top} ) {
             # Skip invalid elements
             next unless defined $field and defined $size and $size > 0;
 
-            my $id = "$type.$field";
+            my $id = "$type-$field";
             # If a term agg and we haven't used this field name, simplify it
             if( $type =~ /terms$/ && !$sub_agg{$field} ) {
                 $id = $field;
@@ -266,7 +269,7 @@ if( exists $OPT{top} ) {
     }
 
     my $field = shift @agg_fields;
-    $agg_header = "count\t" . $field;
+    $agg_header = "count\tpct\t" . $field;
     $agg{$top_agg} = { field => $field };
 
     if( $OPT{'bg-filter'} && $top_agg eq 'significant_terms' ) {
@@ -278,7 +281,7 @@ if( exists $OPT{top} ) {
 
     if( exists $sub_agg{by} ) {
         $agg_header = "$OPT{by}\t" . $agg_header;
-        $agg{$top_agg}->{order} = { by => $ORDER };
+        $agg{$top_agg}->{order} = [ { by => $ORDER }, { "_count" => "desc" } ];
     }
     $agg{aggregations} = \%sub_agg if keys %sub_agg;
 
@@ -302,12 +305,15 @@ if( exists $OPT{top} ) {
     }
 }
 elsif(exists $OPT{tail}) {
-    $q->set_size(20);
+    $q->set_size($CONFIG{'max-batch-size'});
     @AGES = ($AGES[-1]);
 }
-else {
+elsif( $OPT{all} ) {
     $q->set_size( $CONFIG{'max-batch-size'} );
 }
+else {
+    $q->set_size( $CONFIG{size} < $CONFIG{'max-batch-size'} ? $CONFIG{size} : $CONFIG{'max-batch-size'} );
+}
 
 my %displayed_indices = ();
 my $TOTAL_HITS        = 0;
@@ -320,8 +326,11 @@ my $age               = undef;
 my %last_batch_id     = ();
 my %AGGS_TOTALS       = ();
 my %AGES_SEEN         = ();
+# Handle CTRL+C During the Loop
+my $DONE              = 0;
+local $SIG{INT}       = sub { $DONE=1 };
 
-verbose({color=>'green'}, "= Query setup complete, beginning request.");
+verbose({color=>'green',level=>1}, "= Query setup complete, beginning request.");
 AGES: while( !$DONE && @AGES ) {
     # With --tail, we don't want to deplete @AGES
     $age = $OPT{tail} ? $AGES[0] : shift @AGES;
@@ -342,19 +351,14 @@ AGES: while( !$DONE && @AGES ) {
         $header=0;
     }
 
+    debug("== Request Parameters");
+    debug_var($q->uri_params);
     debug("== Query");
-    debug_var($q->request_body);
+    debug(to_json $q->request_body,{allow_nonref=>1,canonical=>1,pretty=>1});
+
+    # Execute the query
+    my $result = $q->execute( $by_age{$age} );
 
-    my $result = es_request('_search',
-        # Search Parameters
-        {
-            index     => $by_age{$age},
-            uri_param => $q->uri_params,
-            method    => 'POST',
-        },
-        # Search Body
-        $q->request_body,
-    );
     debug({clear=>1},"== Results");
     debug_var($result);
     $duration += time() - $start;
@@ -373,15 +377,15 @@ AGES: while( !$DONE && @AGES ) {
         output({stderr=>1,color=>'red'},
             "# Received an error from the cluster. $simple_error"
         );
-        last if $DONE;
-        next;
+        last;
     }
     $displayed_indices{$_} = 1 for @{ $by_age{$age} };
     $TOTAL_HITS += $result->{hits}{total} if $result->{hits}{total};
 
-    my @always = ($CONFIG{timestamp});
-    if(!$OPT{'no-decorators'} && !$header && @SHOW) {
-        output({color=>'cyan'}, join("\t", @always,@SHOW));
+    my @always = ();
+    push @always, $CONFIG{timestamp} unless $OPT{'no-decorators'};
+    if(!$header && @SHOW) {
+        output({color=>'cyan'}, join("\t", @always, @SHOW));
         $header++;
     }
 
@@ -389,102 +393,8 @@ AGES: while( !$DONE && @AGES ) {
         my $hits = is_arrayref($result->{hits}{hits}) ? $result->{hits}{hits} : [];
 
         # Handle Aggregations
-        if( exists $result->{aggregations} ) {
-            my $out_of =  $result->{aggregations}{out_of}{value};
-            $OUT_OF = $out_of if $out_of > $OUT_OF;
-            my $steps = exists $result->{aggregations}{step} ? $result->{aggregations}{step}{buckets}
-                      : [ $result->{aggregations} ];
-            my $indent = exists $result->{aggregations}{step} ? 1 : 0;
-            foreach my $step ( @$steps ) {
-                my $aggs = exists $step->{top} ? $step->{top}{buckets} : [];
-                if( exists $step->{key_as_string} ) {
-                    output({color=>'cyan',clear=>1}, sprintf "%d\t%s", @{$step}{qw(doc_count key_as_string)});
-                }
-                if( @$aggs ) {
-                    # For top the N of T needs to represent maximums
-                    $displayed = scalar(@$aggs) if scalar(@$aggs) > $displayed;
-                    output({color=>'cyan',indent=>$indent},$agg_header) unless $OPT{'no-decorators'};
-                    foreach my $agg ( @$aggs ) {
-                        $AGGS_TOTALS{$agg->{key}} ||= 0;
-                        $AGGS_TOTALS{$agg->{key}} += $agg->{doc_count};
-                        my @out = ();
-
-                        foreach my $k (qw(score doc_count bg_count key)) {
-                            next unless exists $agg->{$k};
-                            my $value = delete $agg->{$k};
-                            push @out, defined $value ? ($k eq 'score' ? sprintf "%0.3f", $value : $value ) : '-';
-                        }
-                        if(exists $agg->{by} ) {
-                            my $by = delete $agg->{by};
-                            if( exists $by->{value} ) {
-                                unshift @out, $by->{value};
-                            }
-                        }
-                        # Handle the --with elements
-                        my %subaggs = ();
-                        if( keys %{ $agg } ) {
-                            foreach my $k (sort keys %{ $agg }) {
-                                next unless is_hashref($agg->{$k});
-                                if( exists $agg->{$k}{buckets} ) {
-                                    my @sub;
-                                    foreach my $subagg (@{ $agg->{$k}{buckets} }) {
-                                        my @elms = ();
-                                        next unless exists $subagg->{key};
-                                        push @elms, $subagg->{key};
-                                        foreach my $dk (qw(score doc_count bg_count)) {
-                                            next unless exists $subagg->{$dk};
-                                            my $v = delete $subagg->{$dk};
-                                            push @elms, defined $v ? ($dk eq 'score' ? sprintf "%0.3f", $v : $v ) : '-';
-                                        }
-                                        push @sub, \@elms;
-                                    }
-                                    $subaggs{$k} = \@sub if @sub;
-                                }
-                                # Simple Numeric Aggs
-                                elsif( $agg->{$k}{value} ) {
-                                    $subaggs{$k} = [ [ $agg->{$k}{value} ] ];
-                                }
-                                # Percentiles
-                                elsif( $agg->{$k}{values} ) {
-                                    my @pcts;
-                                    foreach my $pctl (sort { $a <=> $b } keys %{ $agg->{$k}{values} }) {
-                                        push @pcts, "p$pctl", $agg->{$k}{values}{$pctl};
-                                    }
-                                    $subaggs{$k} = [ \@pcts ];
-                                }
-                                # Statistics
-                                elsif( $agg->{$k}{avg} ) {
-                                    my @stats;
-                                    my %alias = qw( variance var std_deviation stdev );
-                                    foreach my $stat (qw(count min avg max sum variance std_deviation)) {
-                                        next unless exists $agg->{$k}{$stat};
-                                        my $v = $agg->{$k}{$stat} =~ /\./ ? sprintf "%0.3f", $agg->{$k}{$stat}
-                                                                          : $agg->{$k}{$stat};
-                                        push @stats, $alias{$stat} || $stat => $v;
-                                    }
-                                    $subaggs{$k} = [ \@stats ];
-                                }
-                            }
-                        }
-                        if( keys %subaggs ) {
-                            foreach my $subagg (sort keys %subaggs) {
-                                foreach my $extra ( @{ $subaggs{$subagg} } ) {
-                                    output({indent=>$indent,data=>1},
-                                        join "\t", @out, $subagg, @{ $extra }
-                                    );
-                                }
-                            }
-                        }
-                        else {
-                            # Simple output
-                            output({indent=>$indent,data=>!$CONFIG{summary}}, join("\t",@out));
-                        }
-                    }
-                }
-                elsif(exists $result->{aggregations}{top}) {
-                    output({indent=>1,color=>'red'}, "= No results.");
-                }
-            }
+        if( my $aggregations = $result->{aggregations} ) {
+            display_aggregations($aggregations, $result->{hits}{total});
             next AGES;
         }
 
@@ -499,8 +409,14 @@ AGES: while( !$DONE && @AGES ) {
             $last_hit_ts = $hit->{_source}{$CONFIG{timestamp}};
             $last_batch_id{$hit->{_id}}=1;
             my $record = {};
+
+            # Add the _id field to the source so that it is listed
+            # when showing full records and can be and can be
+            # used in @SHOW
+            $hit->{_source}->{_id} = $hit->{_id} unless defined($hit->{_source}->{_id});
+
             if( @SHOW ) {
-                my $flat = flatten( $hit->{_source}, { HashDelimiter=>'.',ArrayDelimiter=>'.' } );
+                my $flat = es_flatten_hash( $hit->{_source} );
                 debug_var($flat);
                 foreach my $f (@always) {
                     $record->{$f} = $flat->{$f};
@@ -563,16 +479,10 @@ AGES: while( !$DONE && @AGES ) {
 
         # Scroll forward
         $start = time;
-        $result = es_request('_search/scroll',
-            {
-                method => 'POST',
-            },
-            {
-                scroll => $q->scroll,
-                scroll_id => $result->{_scroll_id},
-            }
-        );
+        $result = $q->scroll_results();
         $duration += time - $start;
+        # Check if we need to keep going
+        last unless defined $result;
         last unless $result->{hits} && $result->{hits}{hits} && @{ $result->{hits}{hits} } > 0
     }
     last if all_records_displayed();
@@ -600,7 +510,9 @@ if($CONFIG{summary} && keys %AGGS_TOTALS) {
         output({color=>'cyan'},$agg_header);
     }
     foreach my $k (sort { $AGGS_TOTALS{$b} <=> $AGGS_TOTALS{$a} } keys %AGGS_TOTALS) {
-        output({data=>1,color=>'green'},"$AGGS_TOTALS{$k}\t$k");
+        output({data=>1,color=>'green'}, join "\t",
+                $AGGS_TOTALS{$k}, sprintf($CONFIG{decimal_format}, $AGGS_TOTALS{$k} / $TOTAL_HITS), $k
+        );
     }
 }
 
@@ -662,10 +574,11 @@ sub show_fields {
 
 sub show_bases {
     output({color=>'cyan'}, 'Bases available for search:' );
-    my @all   = es_indices(check_date => 0);
+    my @all   = es_indices(_all => 1);
     my %bases = ();
 
     foreach my $index (@all) {
+        next if $index =~ /^\./;
         my $days_old = es_index_days_old( $index ) || 0;
         next unless defined $days_old;
         $days_old = 0 if $days_old < 0;
@@ -696,6 +609,113 @@ sub show_bases {
     );
 }
 
+sub display_aggregations {
+    my ($aggregations,$total_docs) = (@_);
+
+    my $out_of =  $aggregations->{out_of}{value};
+    $OUT_OF = $out_of if $out_of > $OUT_OF;
+    my $steps = exists $aggregations->{step} ? $aggregations->{step}{buckets}
+                : [ $aggregations ];
+    my $indent = exists $aggregations->{step} ? 1 : 0;
+
+    foreach my $step ( @$steps ) {
+        my $aggs = exists $step->{top} ? $step->{top}{buckets} : [];
+        if( exists $step->{key_as_string} ) {
+            output({color=>'cyan',clear=>1}, sprintf "%d\t%s", @{$step}{qw(doc_count key_as_string)});
+        }
+        if( @$aggs ) {
+            # For top the N of T needs to represent maximums
+            $displayed = scalar(@$aggs) if scalar(@$aggs) > $displayed;
+            output({color=>'cyan',indent=>$indent},$agg_header) unless $OPT{'no-decorators'};
+            foreach my $agg ( @$aggs ) {
+                $AGGS_TOTALS{$agg->{key}} ||= 0;
+                $AGGS_TOTALS{$agg->{key}} += $agg->{doc_count};
+                my @out = ();
+                my $top_docs;
+                foreach my $k (qw(score doc_count bg_count key)) {
+                    next unless exists $agg->{$k};
+                    my $value = delete $agg->{$k};
+                    push @out, defined $value ? ($k eq 'score' ? sprintf $CONFIG{decimal_format}, $value : $value ) : '-';
+                    if( $k eq 'doc_count' ) {
+                        push @out, sprintf $CONFIG{decimal_format}, $value ? $value / $total_docs : 0;
+                        $top_docs = $value;
+                    }
+                }
+                if(exists $agg->{by} ) {
+                    my $by = delete $agg->{by};
+                    if( exists $by->{value} ) {
+                        unshift @out, $by->{value};
+                    }
+                }
+                # Handle the --with elements
+                my %subaggs = ();
+                if( keys %{ $agg } ) {
+                    foreach my $k (sort keys %{ $agg }) {
+                        next unless is_hashref($agg->{$k});
+                        if( exists $agg->{$k}{buckets} ) {
+                            my @sub;
+                            foreach my $subagg (@{ $agg->{$k}{buckets} }) {
+                                my @elms = ();
+                                next unless exists $subagg->{key};
+                                push @elms, $subagg->{key};
+                                foreach my $dk (qw(score doc_count bg_count)) {
+                                    next unless exists $subagg->{$dk};
+                                    my $v = delete $subagg->{$dk};
+                                    push @elms, defined $v ? ($dk eq 'score' ? sprintf $CONFIG{decimal_format}, $v : $v ) : '-';
+                                    push @elms, sprintf $CONFIG{decimal_format}, $v / $top_docs
+                                        if $dk eq 'doc_count' and $top_docs;
+                                }
+                                push @sub, \@elms;
+                            }
+                            $subaggs{$k} = \@sub if @sub;
+                        }
+                        # Simple Numeric Aggs
+                        elsif( exists $agg->{$k}{value} ) {
+                            $subaggs{$k} = [ [ $agg->{$k}{value} ] ];
+                        }
+                        # Percentiles
+                        elsif( exists $agg->{$k}{values} ) {
+                            my @pcts;
+                            foreach my $pctl (sort { $a <=> $b } keys %{ $agg->{$k}{values} }) {
+                                push @pcts, "p$pctl", sprintf $CONFIG{decimal_format}, $agg->{$k}{values}{$pctl};
+                            }
+                            $subaggs{$k} = [ \@pcts ];
+                        }
+                        # Statistics
+                        elsif( exists $agg->{$k}{avg} ) {
+                            my @stats;
+                            my %alias = qw( variance var std_deviation stdev );
+                            foreach my $stat (qw(count min avg max sum variance std_deviation)) {
+                                next unless exists $agg->{$k}{$stat};
+                                my $v = $agg->{$k}{$stat} =~ /\./ ? sprintf $CONFIG{decimal_format}, $agg->{$k}{$stat}
+                                                                    : $agg->{$k}{$stat};
+                                push @stats, $alias{$stat} || $stat => $v;
+                            }
+                            $subaggs{$k} = [ \@stats ];
+                        }
+                    }
+                }
+                if( keys %subaggs ) {
+                    foreach my $subagg (sort keys %subaggs) {
+                        foreach my $extra ( @{ $subaggs{$subagg} } ) {
+                            output({indent=>$indent,data=>1},
+                                join "\t", @out, $subagg, @{ $extra }
+                            );
+                        }
+                    }
+                }
+                else {
+                    # Simple output
+                    output({indent=>$indent,data=>!$CONFIG{summary}}, join("\t",@out));
+                }
+            }
+        }
+        elsif(exists $aggregations->{top}) {
+            output({indent=>1,color=>'red'}, "= No results.");
+        }
+    }
+}
+
 sub by_index_age {
     return $ORDER eq 'asc'
         ? $indices{$b} <=> $indices{$a}
@@ -712,7 +732,7 @@ es-search.pl - Provides a CLI for quick searches of data in ElasticSearch daily
 
 =head1 VERSION
 
-version 7.0
+version 7.9.1
 
 =head1 SYNOPSIS
 
@@ -735,6 +755,7 @@ Options:
     --exists            Field which must be present in the document
     --missing           Field which must not be present in the document
     --size              Result size, default is 20, aliased to -n and --limit
+    --max-batch-size    When making requests to ES, retrieve this many docs in a single request, defaults to 50
     --all               Don't consider result size, just give me *everything*
     --asc               Sort by ascending timestamp
     --desc              Sort by descending timestamp (Default)
@@ -742,6 +763,7 @@ Options:
     --format            When --show isn't used, use this method for outputting the record, supported: json, jsonpretty, yaml
                         json assumes --no-decorator as we assume you're piping through jq
     --pretty            Where possible, use JSON->pretty
+    --precision         For floating point values, use this many digits of precision, defaults to 3
     --no-decorators     Do not show the header with field names in the query results
     --no-header         Same as above
     --no-implications   Don't attempt to imply filters from statistical aggregations
@@ -857,6 +879,10 @@ Output format to use when the full record is dumped.  The default is 'yaml', but
 
     --format json
 
+=item B<precision>
+
+For output involving floating point numbers, use this many places to the right of the decimal point.  The default is 3.
+
 =item B<tail>
 
 Repeats the query every second until CTRL+C is hit, displaying new results.  Due to the implementation,
@@ -917,18 +943,18 @@ distinct host) of hosts showing the top 5 hosts
 
 Without the --with, the results might look like this:
 
-    112314 sshd
-    21224  ntp
+    112314 0.151 sshd
+    21224  0.151 ntp
 
 The B<--with> option would expand that output to look like this:
 
-    112314   host   bastion-804   12431   sshd
-    112314   host   bastion-803   10009   sshd
-    112314   host   bastion-805   9768    sshd
-    112314   host   bastion-801   8789    sshd
-    112314   host   bastion-802   4121    sshd
-    21224    host   webapp-324    21223   ntp
-    21224    host   mail-42       1       ntp
+    112314   0.151 host   bastion-804   12431  0.111 sshd
+    112314   0.151 host   bastion-803   10009  0.089 sshd
+    112314   0.151 host   bastion-805   9768   0.087 sshd
+    112314   0.151 host   bastion-801   8789   0.078 sshd
+    112314   0.151 host   bastion-802   4121   0.037 sshd
+    21224    0.016 host   webapp-324    21223  0.999 ntp
+    21224    0.016 host   mail-42       1      0.000 ntp
 
 This may be specified multiple times, the result is more I<rows>, not more I<columns>, e.g.
 
@@ -936,16 +962,16 @@ This may be specified multiple times, the result is more I<rows>, not more I<col
 
 Produces:
 
-    112314   dc     arlington     112314  sshd
-    112314   host   bastion-804   12431   sshd
-    112314   host   bastion-803   10009   sshd
-    112314   host   bastion-805   9768    sshd
-    112314   host   bastion-801   8789    sshd
-    112314   host   bastion-802   4121    sshd
-    21224    dc     amsterdam     21223   ntp
-    21224    dc     la            1       ntp
-    21224    host   webapp-324    21223   ntp
-    21224    host   mail-42       1       ntp
+    112314 0.151  dc     arlington     112314 1.000 sshd
+    112314 0.151  host   bastion-804   12431  0.111 sshd
+    112314 0.151  host   bastion-803   10009  0.089 sshd
+    112314 0.151  host   bastion-805   9768   0.087 sshd
+    112314 0.151  host   bastion-801   8789   0.078 sshd
+    112314 0.151  host   bastion-802   4121   0.037 sshd
+    21224  0.016  dc     amsterdam     21223  0.999 ntp
+    21224  0.016  dc     la            1      0.000 ntp
+    21224  0.016  host   webapp-324    21223  0.999 ntp
+    21224  0.016  host   mail-42       1      0.000 ntp
 
 You may sub aggregate using any L<bucket agggregation|https://www.elastic.co/guide/en/elasticsearch/reference/master/search-aggregations-bucket.html>
 as long as the aggregation provides a B<key> element.  Additionally, doc_count, score, and bg_count will be reported in the output.
@@ -1067,6 +1093,12 @@ Then running:
 
 The number of results to show, default is 20.
 
+=item B<max-batch-size>
+
+When building result sets, this tool uses scroll searches.  This parameter
+controls how many docs are in each scroll.  It defaults to 50, but will be
+scaled down lower if C<size> is smaller.
+
 =item B<all>
 
 If specified, ignore the --size parameter and show me everything within the date range I specified.
@@ -1249,7 +1281,7 @@ Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Brad Lhotsky.
+This software is Copyright (c) 2021 by Brad Lhotsky.
 
 This is free software, licensed under:
 
